@@ -4,16 +4,14 @@ Main interface for lexv2-runtime service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_lexv2_runtime import (
         Client,
         LexRuntimeV2Client,
     )
 
-    session = boto3.Session()
-
-    client: LexRuntimeV2Client = boto3.client("lexv2-runtime")
-    session_client: LexRuntimeV2Client = session.client("lexv2-runtime")
+    session = Session()
+    client: LexRuntimeV2Client = session.client("lexv2-runtime")
     ```
 """
 from .client import LexRuntimeV2Client
